BusCardLayout class

Constructors

BusCardLayout({required BuildContext context, required String referenceNo, required String assessmentCode, required String pickupDatetime, required String pickupLocation, required String dropLocation, required String statusCompany, required List people, required String statusTv, required String spocName, GestureTapCallback? onAcceptTap, GestureTapCallback? onRejectTap, GestureTapCallback? onAssignTap, GestureTapCallback? onApproveTap})

Properties

assessmentCode String
final
context BuildContext
final
dropLocation String
final
hashCode int
The hash code for this object.
no setterinherited
onAcceptTap GestureTapCallback?
final
onApproveTap GestureTapCallback?
final
onAssignTap GestureTapCallback?
final
onRejectTap GestureTapCallback?
final
people List
final
pickupDatetime String
final
pickupLocation String
final
referenceNo String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spocName String
final
statusCompany String
final
statusTv String
final

Methods

newBookingAgent() Widget
newBookingApprover() Widget
normal() Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited