TVTheme class

Constructors

TVTheme()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

blackColor Color
getter/setter pair
borderColor Color
getter/setter pair
boxColor Color
getter/setter pair
busPie Color
getter/setter pair
greyColor Color
getter/setter pair
hotelPie Color
getter/setter pair
primaryColor Color
getter/setter pair
secondColor Color
getter/setter pair
taxiPie Color
Chart Colors
getter/setter pair
trainPie Color
getter/setter pair
transperantColor Color
getter/setter pair
whiteColor Color
getter/setter pair